HMAC

Struct HMAC 

pub struct HMAC<HASH: Hash + Default, const KEY_BUF_LEN: usize = LARGEST_HASHER_BLOCK_LEN> { /* private fields */ }
Internal struct for HKDF. HMAC implements RFC 2104. Can, in theory, be instantiated with hash functions other than the ones provided by this crate (even custom ones).

Implementations

Source

impl HMAC<SHA224, 64>

pub fn keygen() -> Result<KeyMaterial<28>, RNGError>

Generate a key of the appropriate length for the given HMAC

Source

impl HMAC<SHA256, 64>

pub fn keygen() -> Result<KeyMaterial<32>, RNGError>

Generate a key of the appropriate length for the given HMAC

Source

impl HMAC<SHA384, 128>

pub fn keygen() -> Result<KeyMaterial<48>, RNGError>

Generate a key of the appropriate length for the given HMAC

Source

impl HMAC<SHA512, 128>

pub fn keygen() -> Result<KeyMaterial<64>, RNGError>

Generate a key of the appropriate length for the given HMAC

Source

impl HMAC<SHA3_224, 144>

pub fn keygen() -> Result<KeyMaterial<28>, RNGError>

Generate a key of the appropriate length for the given HMAC

Source

impl HMAC<SHA3_256, 136>

pub fn keygen() -> Result<KeyMaterial<32>, RNGError>

Generate a key of the appropriate length for the given HMAC

Source

impl HMAC<SHA3_384, 104>

pub fn keygen() -> Result<KeyMaterial<48>, RNGError>

Generate a key of the appropriate length for the given HMAC

Source

impl HMAC<SHA3_512, 72>

pub fn keygen() -> Result<KeyMaterial<64>, RNGError>

Generate a key of the appropriate length for the given HMAC