pub type HMAC_SHA224 = HMAC<SHA224, 64>;Expand description
Public type for HMAC using SHA224.
Aliased Type
pub struct HMAC_SHA224 { /* private fields */ }Trait Implementations
Sourceimpl Algorithm for HMAC_SHA224
impl Algorithm for HMAC_SHA224
Sourceconst ALG_NAME: &'static str = HMAC_SHA224_NAME
const ALG_NAME: &'static str = HMAC_SHA224_NAME
String name for the algorithm, used consistently across the library.
Sourceconst MAX_SECURITY_STRENGTH: SecurityStrength = SecurityStrength::_112bit
const MAX_SECURITY_STRENGTH: SecurityStrength = SecurityStrength::_112bit
Maximum security strength supported by the algorithm.
In other words, this algorithm can produce outputs up to this security strength,
but may produce outputs with lower security strength, for example, if asked to truncate.