pub type HMAC_SHA256 = HMAC<SHA256, 64>;Expand description
Public type for HKDF using SHA256.
Aliased Type
pub struct HMAC_SHA256 { /* private fields */ }Trait Implementations
Sourceimpl Algorithm for HMAC_SHA256
impl Algorithm for HMAC_SHA256
Sourceconst ALG_NAME: &'static str = HMAC_SHA256_NAME
const ALG_NAME: &'static str = HMAC_SHA256_NAME
String name for the algorithm, used consistently across the library.
Sourceconst MAX_SECURITY_STRENGTH: SecurityStrength = SecurityStrength::_128bit
const MAX_SECURITY_STRENGTH: SecurityStrength = SecurityStrength::_128bit
Maximum security strength supported by the algorithm.
In other words, this algorithm can produce outputs up to this security strength,
but may produce outputs with lower security strength, for example, if asked to truncate.