pub type HMAC_SHA3_512 = HMAC<SHA3_512, 72>;Expand description
Public type for HKDF using SHA3_512.
Aliased Type
pub struct HMAC_SHA3_512 { /* private fields */ }Trait Implementations
Sourceimpl Algorithm for HMAC_SHA3_512
impl Algorithm for HMAC_SHA3_512
Sourceconst ALG_NAME: &'static str = HMAC_SHA3_512_NAME
const ALG_NAME: &'static str = HMAC_SHA3_512_NAME
String name for the algorithm, used consistently across the library.
Sourceconst MAX_SECURITY_STRENGTH: SecurityStrength = SecurityStrength::_256bit
const MAX_SECURITY_STRENGTH: SecurityStrength = SecurityStrength::_256bit
Maximum security strength supported by the algorithm.
In other words, this algorithm can produce outputs up to this security strength,
but may produce outputs with lower security strength, for example, if asked to truncate.