pub struct HMAC<HASH: Hash + Default, const KEY_BUF_LEN: usize = LARGEST_HASHER_BLOCK_LEN> { /* private fields */ }Expand description
Internal struct for HKDF. HMAC implements RFC 2104. Can, in theory, be instantiated with hash functions other than the ones provided by this crate (even custom ones).
Implementations
Sourceimpl HMAC<SHA224, 64>
impl HMAC<SHA224, 64>
Sourcepub fn keygen() -> Result<KeyMaterial<28>, RNGError>
pub fn keygen() -> Result<KeyMaterial<28>, RNGError>
Generate a key of the appropriate length for the given HMAC
Sourceimpl HMAC<SHA256, 64>
impl HMAC<SHA256, 64>
Sourcepub fn keygen() -> Result<KeyMaterial<32>, RNGError>
pub fn keygen() -> Result<KeyMaterial<32>, RNGError>
Generate a key of the appropriate length for the given HMAC
Sourceimpl HMAC<SHA384, 128>
impl HMAC<SHA384, 128>
Sourcepub fn keygen() -> Result<KeyMaterial<48>, RNGError>
pub fn keygen() -> Result<KeyMaterial<48>, RNGError>
Generate a key of the appropriate length for the given HMAC
Sourceimpl HMAC<SHA512, 128>
impl HMAC<SHA512, 128>
Sourcepub fn keygen() -> Result<KeyMaterial<64>, RNGError>
pub fn keygen() -> Result<KeyMaterial<64>, RNGError>
Generate a key of the appropriate length for the given HMAC
Sourceimpl HMAC<SHA3_224, 144>
impl HMAC<SHA3_224, 144>
Sourcepub fn keygen() -> Result<KeyMaterial<28>, RNGError>
pub fn keygen() -> Result<KeyMaterial<28>, RNGError>
Generate a key of the appropriate length for the given HMAC
Sourceimpl HMAC<SHA3_256, 136>
impl HMAC<SHA3_256, 136>
Sourcepub fn keygen() -> Result<KeyMaterial<32>, RNGError>
pub fn keygen() -> Result<KeyMaterial<32>, RNGError>
Generate a key of the appropriate length for the given HMAC